"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const cli_utils_1 = require("@pnpm/cli-utils");
const error_1 = require("@pnpm/error");
const render_help_1 = __importDefault(require("render-help"));
const envRemove_1 = require("./envRemove");
const envUse_1 = require("./envUse");
const envList_1 = require("./envList");
function rcOptionsTypes() {
    return {};
}
exports.rcOptionsTypes = rcOptionsTypes;
function cliOptionsTypes() {
    return {
        global: Boolean,
        remote: Boolean,
    };
}
exports.cliOptionsTypes = cliOptionsTypes;
exports.commandNames = ['env'];
function help() {
    return (0, render_help_1.default)({
        description: 'Manage Node.js versions.',
        descriptionLists: [
            {
                title: 'Commands',
                list: [
                    {
                        description: 'Installs the specified version of Node.js. The npm CLI bundled with the given Node.js version gets installed as well.',
                        name: 'use',
                    },
                    {
                        description: 'Removes the specified version of Node.js.',
                        name: 'remove',
                        shortAlias: 'rm',
                    },
                    {
                        description: 'List Node.js versions available locally or remotely',
                        name: 'list',
                        shortAlias: 'ls',
                    },
                ],
            },
            {
                title: 'Options',
                list: [
                    {
                        description: 'Manages Node.js versions globally',
                        name: '--global',
                        shortAlias: '-g',
                    },
                    {
                        description: 'List the remote versions of Node.js',
                        name: '--remote',
                    },
                ],
            },
        ],
        url: (0, cli_utils_1.docsUrl)('env'),
        usages: [
            'pnpm env [command] [options] <version>',
            'pnpm env use --global 16',
            'pnpm env use --global lts',
            'pnpm env use --global argon',
            'pnpm env use --global latest',
            'pnpm env use --global rc/16',
            'pnpm env remove --global 16',
            'pnpm env remove --global lts',
            'pnpm env remove --global argon',
            'pnpm env remove --global latest',
            'pnpm env remove --global rc/16',
            'pnpm env list',
            'pnpm env list --remote',
            'pnpm env list --remote 16',
            'pnpm env list --remote lts',
            'pnpm env list --remote argon',
            'pnpm env list --remote latest',
            'pnpm env list --remote rc/16',
        ],
    });
}
exports.help = help;
async function handler(opts, params) {
    if (params.length === 0) {
        throw new error_1.PnpmError('ENV_NO_SUBCOMMAND', 'Please specify the subcommand');
    }
    switch (params[0]) {
        case 'use': {
            return (0, envUse_1.envUse)(opts, params.slice(1));
        }
        case 'remove':
        case 'rm':
        case 'uninstall':
        case 'un': {
            return (0, envRemove_1.envRemove)(opts, params.slice(1));
        }
        case 'list':
        case 'ls': {
            return (0, envList_1.envList)(opts, params.slice(1));
        }
        default: {
            throw new error_1.PnpmError('ENV_UNKNOWN_SUBCOMMAND', 'This subcommand is not known');
        }
    }
}
exports.handler = handler;
//# sourceMappingURL=env.js.map