"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.envUse = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const error_1 = require("@pnpm/error");
const fetch_1 = require("@pnpm/fetch");
const node_resolver_1 = require("@pnpm/node.resolver");
const cmd_shim_1 = __importDefault(require("@zkochan/cmd-shim"));
const node_1 = require("./node");
const getNodeMirror_1 = require("./getNodeMirror");
const parseNodeEditionSpecifier_1 = require("./parseNodeEditionSpecifier");
const utils_1 = require("./utils");
async function envUse(opts, params) {
    if (!opts.global) {
        throw new error_1.PnpmError('NOT_IMPLEMENTED_YET', '"pnpm env use <version>" can only be used with the "--global" option currently');
    }
    const fetch = (0, fetch_1.createFetchFromRegistry)(opts);
    const { releaseChannel, versionSpecifier } = (0, parseNodeEditionSpecifier_1.parseNodeEditionSpecifier)(params[0]);
    const nodeMirrorBaseUrl = (0, getNodeMirror_1.getNodeMirror)(opts.rawConfig, releaseChannel);
    const nodeVersion = await (0, node_resolver_1.resolveNodeVersion)(fetch, versionSpecifier, nodeMirrorBaseUrl);
    if (!nodeVersion) {
        throw new error_1.PnpmError('COULD_NOT_RESOLVE_NODEJS', `Couldn't find Node.js version matching ${params[0]}`);
    }
    const nodeDir = await (0, node_1.getNodeDir)(fetch, {
        ...opts,
        useNodeVersion: nodeVersion,
        nodeMirrorBaseUrl,
    });
    const src = (0, utils_1.getNodeExecPathInNodeDir)(nodeDir);
    const dest = (0, utils_1.getNodeExecPathInBinDir)(opts.bin);
    try {
        await fs_1.promises.unlink(dest);
    }
    catch (err) { }
    await fs_1.promises.symlink(src, dest, 'file');
    try {
        let npmDir = nodeDir;
        if (process.platform !== 'win32') {
            npmDir = path_1.default.join(npmDir, 'lib');
        }
        npmDir = path_1.default.join(npmDir, 'node_modules/npm');
        if (opts.configDir) {
            // We want the global npm settings to persist when Node.js or/and npm is changed to a different version,
            // so we tell npm to read the global config from centralized place that is outside of npm's directory.
            await fs_1.promises.writeFile(path_1.default.join(npmDir, 'npmrc'), `globalconfig=${path_1.default.join(opts.configDir, 'npmrc')}`, 'utf-8');
        }
        const npmBinDir = path_1.default.join(npmDir, 'bin');
        const cmdShimOpts = { createPwshFile: false };
        await (0, cmd_shim_1.default)(path_1.default.join(npmBinDir, 'npm-cli.js'), path_1.default.join(opts.bin, 'npm'), cmdShimOpts);
        await (0, cmd_shim_1.default)(path_1.default.join(npmBinDir, 'npx-cli.js'), path_1.default.join(opts.bin, 'npx'), cmdShimOpts);
    }
    catch (err) { // eslint-disable-line
        // ignore
    }
    return `Node.js ${nodeVersion} is activated
${dest} -> ${src}`;
}
exports.envUse = envUse;
//# sourceMappingURL=envUse.js.map